/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataDatadogServiceAccountConfig extends cdktf.TerraformMetaArguments {
    /**
    * Filter all users and service accounts by name, email, or role.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/data-sources/service_account#filter DataDatadogServiceAccount#filter}
    */
    readonly filter?: string;
    /**
    * Filter on status attribute. Comma separated list, with possible values `Active`, `Pending`, and `Disabled`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/data-sources/service_account#filter_status DataDatadogServiceAccount#filter_status}
    */
    readonly filterStatus?: string;
    /**
    * The service account's ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/data-sources/service_account#id DataDatadogServiceAccount#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/data-sources/service_account datadog_service_account}
*/
export declare class DataDatadogServiceAccount extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "datadog_service_account";
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/data-sources/service_account datadog_service_account} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataDatadogServiceAccountConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataDatadogServiceAccountConfig);
    get disabled(): cdktf.IResolvable;
    get email(): string;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    private _filterStatus?;
    get filterStatus(): string;
    set filterStatus(value: string);
    resetFilterStatus(): void;
    get filterStatusInput(): string | undefined;
    get handle(): string;
    get icon(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    get roles(): string[];
    get status(): string;
    get title(): string;
    get verified(): cdktf.IResolvable;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
