/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface TeamLinkConfig extends cdktf.TerraformMetaArguments {
    /**
    * The link's label.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/resources/team_link#label TeamLink#label}
    */
    readonly label: string;
    /**
    * The link's position, used to sort links for the team.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/resources/team_link#position TeamLink#position}
    */
    readonly position?: number;
    /**
    * ID of the team the link is associated with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/resources/team_link#team_id TeamLink#team_id}
    */
    readonly teamId: string;
    /**
    * The URL for the link.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/resources/team_link#url TeamLink#url}
    */
    readonly url: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/resources/team_link datadog_team_link}
*/
export declare class TeamLink extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_team_link";
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.28.0/docs/resources/team_link datadog_team_link} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options TeamLinkConfig
    */
    constructor(scope: Construct, id: string, config: TeamLinkConfig);
    get id(): string;
    private _label?;
    get label(): string;
    set label(value: string);
    get labelInput(): string | undefined;
    private _position?;
    get position(): number;
    set position(value: number);
    resetPosition(): void;
    get positionInput(): number | undefined;
    private _teamId?;
    get teamId(): string;
    set teamId(value: string);
    get teamIdInput(): string | undefined;
    private _url?;
    get url(): string;
    set url(value: string);
    get urlInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
